@@ -18,11 +18,11 @@ class sdk:
         else:
             cookie = json.loads(base64.b64decode(base64Cookie))
             self.skoleId = cookie["LastLoginExamno"]
+            self.elevId = cookie["LastLoginElevId"]
 
             for identifier, value in cookie.items():
                 self.session.cookies.set(identifier, value, domain="lectio.dk")
 
-            self.elevId = self.fåSkoleId()
 
 
     def login(self):
@@ -86,6 +86,12 @@ class sdk:
         if not successful:
             raise Exception("Kunne ikke finde elev id. Rapporter venligst dette på Github")
 
+    def base64Cookie(self):
+        cookie = self.session.cookies.get_dict()
+        cookie["LastLoginElevId"] = self.elevId
+
+        return base64.b64encode(json.dumps(cookie).encode())
+
     def fåSkoleId(self):
         resp = self.session.get("https://www.lectio.dk/lectio/681/forside.aspx")
         soup = BeautifulSoup(resp.text, "html.parser")
@@ -143,8 +149,8 @@ class sdk:
                 "aktivitet": modulDict,
                 "note": tr.find_all("td")[1].text,
                 "lektier": {
-                    "beskrivelse": tr.find_all("a")[1].text,
-                    "link": tr.find_all("a")[1].get("href")
+                    "beskrivelse": tr.find("td", {"class": "ls-homework"}).find("a").text,
+                    "link": tr.find("td", {"class": "ls-homework"}).find("a").get("href")
                 }
             }
 
@@ -172,7 +178,8 @@ class sdk:
         skema = {
             "modulTider": {},
             "ugeDage": [],
-            "moduler": []
+            "moduler": [],
+            "dagsNoter": []
         }
 
         for modulTid in soup.find_all("div", {"class": "s2module-info"}):
@@ -182,6 +189,15 @@ class sdk:
             if dag.text != "":
                 skema["ugeDage"].append(dag.text)
 
+        i = 0
+        for dagsNoter in soup.find_all("td", {"class": "s2infoHeader s2skemabrikcontainer"}):
+            skema["dagsNoter"].append({
+                skema["ugeDage"][i]: []
+            })
+            for dagsNote in dagsNoter.find_all("a"):
+                skema["dagsNoter"][i][skema["ugeDage"][i]].append(dagsNote.text.lstrip())
+            i += 1
+
         successful = False
         i = 0
 
